@@ -2,7 +2,7 @@ package Role::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '2.002_001';
+our $VERSION = '2.002_002';
 $VERSION =~ tr/_//d;
 
 our %INFO;
@@ -53,6 +53,10 @@ sub _load_module {
   return 1;
 }
 
+sub _require_module {
+  _load_module($_[1]);
+}
+
 sub _all_subs {
   my ($me, $package) = @_;
   my $stash = _getstash($package);
@@ -197,10 +201,17 @@ sub create_class_with_roles {
 
   my $new_name = $me->_composite_name($superclass, @roles);
 
-  return $new_name if $COMPOSED{class}{$new_name};
+  return $new_name
+    if $COMPOSED{class}{$new_name};
+
+  return $me->_build_class_with_roles($new_name, $superclass, @roles);
+}
+
+sub _build_class_with_roles {
+  my ($me, $new_name, $superclass, @roles) = @_;
 
   $COMPOSED{base}{$new_name} = $superclass;
-  *{_getglob("${new_name}::ISA")} = [ $superclass ];
+  @{*{_getglob("${new_name}::ISA")}} = ( $superclass );
   $me->apply_roles_to_package($new_name, @roles);
   $COMPOSED{class}{$new_name} = 1;
   return $new_name;
@@ -216,8 +227,8 @@ sub _check_roles {
   }
 
   foreach my $role (@roles) {
-    _load_module($role);
-    croak "${role} is not a Role::Tiny" unless $me->is_role($role);
+    $me->_require_module($role);
+    croak "${role} is not a ${me}" unless $me->is_role($role);
   }
 }
 
@@ -375,7 +386,8 @@ sub _concrete_methods_of {
 
 sub methods_provided_by {
   my ($me, $role) = @_;
-  croak "${role} is not a Role::Tiny" unless $me->is_role($role);
+  $me->_require_module($role);
+  croak "${role} is not a ${me}" unless $me->is_role($role);
   sort (keys %{$me->_concrete_methods_of($role)}, @{$INFO{$role}->{requires}||[]});
 }
 
